@@ -26,6 +26,10 @@ mlr3tuning::TuningInstanceMultiCrit
 #' @export
 mlr3tuning::extract_inner_tuning_results
 
+#' @importFrom mlr3tuning extract_inner_tuning_archives
+#' @export
+mlr3tuning::extract_inner_tuning_archives
+
 #' @importFrom mlr3tuning tune
 #' @export
 mlr3tuning::tune
